@@ -18,9 +18,9 @@ typedef struct _tabwrite_tilde
     t_object x_obj;
     int x_phase;
     int x_nsampsintab;
-    float *x_vec;
+    t_word *x_vec;
     t_symbol *x_arrayname;
-    float x_f;
+    t_float x_f;
 } t_tabwrite_tilde;
 
 static void tabwrite_tilde_tick(t_tabwrite_tilde *x);
@@ -45,22 +45,22 @@ static void tabwrite_tilde_redraw(t_tabwrite_tilde *x)
 static t_int *tabwrite_tilde_perform(t_int *w)
 {
     t_tabwrite_tilde *x = (t_tabwrite_tilde *)(w[1]);
-    t_float *in = (t_float *)(w[2]);
+    t_sample *in = (t_sample *)(w[2]);
     int n = (int)(w[3]), phase = x->x_phase, endphase = x->x_nsampsintab;
     if (!x->x_vec) goto bad;
     
     if (endphase > phase)
     {
         int nxfer = endphase - phase;
-        float *fp = x->x_vec + phase;
+        t_word *wp = x->x_vec + phase;
         if (nxfer > n) nxfer = n;
         phase += nxfer;
         while (nxfer--)
         {
-            float f = *in++;
+            t_sample f = *in++;
             if (PD_BIGORSMALL(f))
                 f = 0;
-            *fp++ = f;
+            (wp++)->w_float = f;
         }
         if (phase >= endphase)
         {
@@ -85,7 +85,7 @@ void tabwrite_tilde_set(t_tabwrite_tilde *x, t_symbol *s)
             x->x_arrayname->s_name);
         x->x_vec = 0;
     }
-    else if (!garray_getfloatarray(a, &x->x_nsampsintab, &x->x_vec))
+    else if (!garray_getfloatwords(a, &x->x_nsampsintab, &x->x_vec))
     {
         pd_error(x, "%s: bad template for tabwrite~", x->x_arrayname->s_name);
         x->x_vec = 0;
@@ -146,7 +146,7 @@ typedef struct _tabplay_tilde
     int x_phase;
     int x_nsampsintab;
     int x_limit;
-    float *x_vec;
+    t_word *x_vec;
     t_symbol *x_arrayname;
     t_clock *x_clock;
 } t_tabplay_tilde;
@@ -168,7 +168,8 @@ static void *tabplay_tilde_new(t_symbol *s)
 static t_int *tabplay_tilde_perform(t_int *w)
 {
     t_tabplay_tilde *x = (t_tabplay_tilde *)(w[1]);
-    t_float *out = (t_float *)(w[2]), *fp;
+    t_sample *out = (t_sample *)(w[2]);
+    t_word *wp;
     int n = (int)(w[3]), phase = x->x_phase,
         endphase = (x->x_nsampsintab < x->x_limit ?
             x->x_nsampsintab : x->x_limit), nxfer, n3;
@@ -176,13 +177,13 @@ static t_int *tabplay_tilde_perform(t_int *w)
         goto zero;
     
     nxfer = endphase - phase;
-    fp = x->x_vec + phase;
+    wp = x->x_vec + phase;
     if (nxfer > n)
         nxfer = n;
     n3 = n - nxfer;
     phase += nxfer;
     while (nxfer--)
-        *out++ = *fp++;
+        *out++ = (wp++)->w_float;
     if (phase >= endphase)
     {
         clock_delay(x->x_clock, 0);
@@ -209,7 +210,7 @@ void tabplay_tilde_set(t_tabplay_tilde *x, t_symbol *s)
             x->x_arrayname->s_name);
         x->x_vec = 0;
     }
-    else if (!garray_getfloatarray(a, &x->x_nsampsintab, &x->x_vec))
+    else if (!garray_getfloatwords(a, &x->x_nsampsintab, &x->x_vec))
     {
         pd_error(x, "%s: bad template for tabplay~", x->x_arrayname->s_name);
         x->x_vec = 0;
@@ -273,9 +274,9 @@ typedef struct _tabread_tilde
 {
     t_object x_obj;
     int x_npoints;
-    float *x_vec;
+    t_word *x_vec;
     t_symbol *x_arrayname;
-    float x_f;
+    t_float x_f;
 } t_tabread_tilde;
 
 static void *tabread_tilde_new(t_symbol *s)
@@ -291,11 +292,11 @@ static void *tabread_tilde_new(t_symbol *s)
 static t_int *tabread_tilde_perform(t_int *w)
 {
     t_tabread_tilde *x = (t_tabread_tilde *)(w[1]);
-    t_float *in = (t_float *)(w[2]);
-    t_float *out = (t_float *)(w[3]);
+    t_sample *in = (t_sample *)(w[2]);
+    t_sample *out = (t_sample *)(w[3]);
     int n = (int)(w[4]);    
     int maxindex;
-    float *buf = x->x_vec, *fp;
+    t_word *buf = x->x_vec;
     int i;
     
     maxindex = x->x_npoints - 1;
@@ -308,7 +309,7 @@ static t_int *tabread_tilde_perform(t_int *w)
             index = 0;
         else if (index > maxindex)
             index = maxindex;
-        *out++ = buf[index];
+        *out++ = buf[index].w_float;
     }
     return (w+5);
  zero:
@@ -328,7 +329,7 @@ void tabread_tilde_set(t_tabread_tilde *x, t_symbol *s)
             pd_error(x, "tabread~: %s: no such array", x->x_arrayname->s_name);
         x->x_vec = 0;
     }
-    else if (!garray_getfloatarray(a, &x->x_npoints, &x->x_vec))
+    else if (!garray_getfloatwords(a, &x->x_npoints, &x->x_vec))
     {
         pd_error(x, "%s: bad template for tabread~", x->x_arrayname->s_name);
         x->x_vec = 0;
@@ -369,9 +370,9 @@ typedef struct _tabread4_tilde
 {
     t_object x_obj;
     int x_npoints;
-    float *x_vec;
+    t_word *x_vec;
     t_symbol *x_arrayname;
-    float x_f;
+    t_float x_f;
 } t_tabread4_tilde;
 
 static void *tabread4_tilde_new(t_symbol *s)
@@ -387,11 +388,11 @@ static void *tabread4_tilde_new(t_symbol *s)
 static t_int *tabread4_tilde_perform(t_int *w)
 {
     t_tabread4_tilde *x = (t_tabread4_tilde *)(w[1]);
-    t_float *in = (t_float *)(w[2]);
-    t_float *out = (t_float *)(w[3]);
+    t_sample *in = (t_sample *)(w[2]);
+    t_sample *out = (t_sample *)(w[3]);
     int n = (int)(w[4]);    
     int maxindex;
-    float *buf = x->x_vec, *fp;
+    t_word *buf = x->x_vec, *wp;
     int i;
     
     maxindex = x->x_npoints - 3;
@@ -401,7 +402,7 @@ static t_int *tabread4_tilde_perform(t_int *w)
 #if 0       /* test for spam -- I'm not ready to deal with this */
     for (i = 0,  xmax = 0, xmin = maxindex,  fp = in1; i < n; i++,  fp++)
     {
-        float f = *in1;
+        t_sample f = *in1;
         if (f < xmin) xmin = f;
         else if (f > xmax) xmax = f;
     }
@@ -409,27 +410,27 @@ static t_int *tabread4_tilde_perform(t_int *w)
     for (i = 0, splitlo = xmin+ x->c_maxextent, splithi = xmax - x->c_maxextent,
         fp = in1; i < n; i++,  fp++)
     {
-        float f = *in1;
+        t_sample f = *in1;
         if (f > splitlo && f < splithi) goto zero;
     }
 #endif
 
     for (i = 0; i < n; i++)
     {
-        float findex = *in++;
+        t_sample findex = *in++;
         int index = findex;
-        float frac,  a,  b,  c,  d, cminusb;
+        t_sample frac,  a,  b,  c,  d, cminusb;
         static int count;
         if (index < 1)
             index = 1, frac = 0;
         else if (index > maxindex)
             index = maxindex, frac = 1;
         else frac = findex - index;
-        fp = buf + index;
-        a = fp[-1];
-        b = fp[0];
-        c = fp[1];
-        d = fp[2];
+        wp = buf + index;
+        a = wp[-1].w_float;
+        b = wp[0].w_float;
+        c = wp[1].w_float;
+        d = wp[2].w_float;
         /* if (!i && !(count++ & 1023))
             post("fp = %lx,  shit = %lx,  b = %f",  fp, buf->b_shit,  b); */
         cminusb = c-b;
@@ -457,7 +458,7 @@ void tabread4_tilde_set(t_tabread4_tilde *x, t_symbol *s)
             pd_error(x, "tabread4~: %s: no such array", x->x_arrayname->s_name);
         x->x_vec = 0;
     }
-    else if (!garray_getfloatarray(a, &x->x_npoints, &x->x_vec))
+    else if (!garray_getfloatwords(a, &x->x_npoints, &x->x_vec))
     {
         pd_error(x, "%s: bad template for tabread4~", x->x_arrayname->s_name);
         x->x_vec = 0;
@@ -492,6 +493,7 @@ static void tabread4_tilde_setup(void)
 
 /******************** tabosc4~ ***********************/
 
+/* this is all copied from d_osc.c... what include file could this go in? */
 #define UNITBIT32 1572864.  /* 3*2^19; bit 32 has place value 1 */
 
     /* machine-dependent definitions.  These ifdefs really
@@ -545,13 +547,13 @@ static t_class *tabosc4_tilde_class;
 typedef struct _tabosc4_tilde
 {
     t_object x_obj;
-    float x_fnpoints;
-    float x_finvnpoints;
-    float *x_vec;
+    t_float x_fnpoints;
+    t_float x_finvnpoints;
+    t_word *x_vec;
     t_symbol *x_arrayname;
-    float x_f;
+    t_float x_f;
     double x_phase;
-    float x_conv;
+    t_float x_conv;
 } t_tabosc4_tilde;
 
 static void *tabosc4_tilde_new(t_symbol *s)
@@ -570,16 +572,16 @@ static void *tabosc4_tilde_new(t_symbol *s)
 static t_int *tabosc4_tilde_perform(t_int *w)
 {
     t_tabosc4_tilde *x = (t_tabosc4_tilde *)(w[1]);
-    t_float *in = (t_float *)(w[2]);
-    t_float *out = (t_float *)(w[3]);
+    t_sample *in = (t_sample *)(w[2]);
+    t_sample *out = (t_sample *)(w[3]);
     int n = (int)(w[4]);
     int normhipart;
     union tabfudge tf;
-    float fnpoints = x->x_fnpoints;
+    t_float fnpoints = x->x_fnpoints;
     int mask = fnpoints - 1;
-    float conv = fnpoints * x->x_conv;
+    t_float conv = fnpoints * x->x_conv;
     int maxindex;
-    float *tab = x->x_vec, *addr;
+    t_word *tab = x->x_vec, *addr;
     int i;
     double dphase = fnpoints * x->x_phase + UNITBIT32;
 
@@ -590,16 +592,16 @@ static t_int *tabosc4_tilde_perform(t_int *w)
 #if 1
     while (n--)
     {
-        float frac,  a,  b,  c,  d, cminusb;
+        t_sample frac,  a,  b,  c,  d, cminusb;
         tf.tf_d = dphase;
         dphase += *in++ * conv;
         addr = tab + (tf.tf_i[HIOFFSET] & mask);
         tf.tf_i[HIOFFSET] = normhipart;
         frac = tf.tf_d - UNITBIT32;
-        a = addr[0];
-        b = addr[1];
-        c = addr[2];
-        d = addr[3];
+        a = addr[0].w_float;
+        b = addr[1].w_float;
+        c = addr[2].w_float;
+        d = addr[3].w_float;
         cminusb = c-b;
         *out++ = b + frac * (
             cminusb - 0.1666667f * (1.-frac) * (
@@ -633,7 +635,7 @@ void tabosc4_tilde_set(t_tabosc4_tilde *x, t_symbol *s)
             pd_error(x, "tabosc4~: %s: no such array", x->x_arrayname->s_name);
         x->x_vec = 0;
     }
-    else if (!garray_getfloatarray(a, &pointsinarray, &x->x_vec))
+    else if (!garray_getfloatwords(a, &pointsinarray, &x->x_vec))
     {
         pd_error(x, "%s: bad template for tabosc4~", x->x_arrayname->s_name);
         x->x_vec = 0;
@@ -688,11 +690,11 @@ static t_class *tabsend_class;
 typedef struct _tabsend
 {
     t_object x_obj;
-    float *x_vec;
+    t_word *x_vec;
     int x_graphperiod;
     int x_graphcount;
     t_symbol *x_arrayname;
-    float x_f;
+    t_float x_f;
 } t_tabsend;
 
 static void tabsend_tick(t_tabsend *x);
@@ -709,18 +711,18 @@ static void *tabsend_new(t_symbol *s)
 static t_int *tabsend_perform(t_int *w)
 {
     t_tabsend *x = (t_tabsend *)(w[1]);
-    t_float *in = (t_float *)(w[2]);
+    t_sample *in = (t_sample *)(w[2]);
     int n = w[3];
-    t_float *dest = x->x_vec;
+    t_word *dest = x->x_vec;
     int i = x->x_graphcount;
     if (!x->x_vec) goto bad;
 
     while (n--)
     {   
-        float f = *in++;
+        t_sample f = *in++;
         if (PD_BIGORSMALL(f))
             f = 0;
-         *dest++ = f;
+         (dest++)->w_float = f;
     }
     if (!i--)
     {
@@ -745,7 +747,7 @@ static void tabsend_dsp(t_tabsend *x, t_signal **sp)
         if (*x->x_arrayname->s_name)
             pd_error(x, "tabsend~: %s: no such array", x->x_arrayname->s_name);
     }
-    else if (!garray_getfloatarray(a, &vecsize, &x->x_vec))
+    else if (!garray_getfloatwords(a, &vecsize, &x->x_vec))
         pd_error(x, "%s: bad template for tabsend~", x->x_arrayname->s_name);
     else
     {
@@ -775,7 +777,7 @@ static t_class *tabreceive_class;
 typedef struct _tabreceive
 {
     t_object x_obj;
-    float *x_vec;
+    t_word *x_vec;
     int x_vecsize;
     t_symbol *x_arrayname;
 } t_tabreceive;
@@ -783,14 +785,14 @@ typedef struct _tabreceive
 static t_int *tabreceive_perform(t_int *w)
 {
     t_tabreceive *x = (t_tabreceive *)(w[1]);
-    t_float *out = (t_float *)(w[2]);
+    t_sample *out = (t_sample *)(w[2]);
     int n = w[3];
-    t_float *from = x->x_vec;
+    t_word *from = x->x_vec;
     if (from)
     {
         int vecsize = x->x_vecsize;
         while (vecsize--)
-            *out++ = *from++;
+            *out++ = (from++)->w_float;
         vecsize = n - x->x_vecsize;
         while (vecsize--)
             *out++ = 0;
@@ -807,7 +809,7 @@ static void tabreceive_dsp(t_tabreceive *x, t_signal **sp)
         if (*x->x_arrayname->s_name)
             pd_error(x, "tabsend~: %s: no such array", x->x_arrayname->s_name);
     }
-    else if (!garray_getfloatarray(a, &x->x_vecsize, &x->x_vec))
+    else if (!garray_getfloatwords(a, &x->x_vecsize, &x->x_vec))
         pd_error(x, "%s: bad template for tabreceive~", x->x_arrayname->s_name);
     else 
     {
@@ -849,18 +851,18 @@ static void tabread_float(t_tabread *x, t_float f)
 {
     t_garray *a;
     int npoints;
-    t_float *vec;
+    t_word *vec;
 
     if (!(a = (t_garray *)pd_findbyclass(x->x_arrayname, garray_class)))
         pd_error(x, "%s: no such array", x->x_arrayname->s_name);
-    else if (!garray_getfloatarray(a, &npoints, &vec))
+    else if (!garray_getfloatwords(a, &npoints, &vec))
         pd_error(x, "%s: bad template for tabread", x->x_arrayname->s_name);
     else
     {
         int n = f;
         if (n < 0) n = 0;
         else if (n >= npoints) n = npoints - 1;
-        outlet_float(x->x_obj.ob_outlet, (npoints ? vec[n] : 0));
+        outlet_float(x->x_obj.ob_outlet, (npoints ? vec[n].w_float : 0));
     }
 }
 
@@ -900,30 +902,31 @@ static void tabread4_float(t_tabread4 *x, t_float f)
 {
     t_garray *a;
     int npoints;
-    t_float *vec;
+    t_word *vec;
 
     if (!(a = (t_garray *)pd_findbyclass(x->x_arrayname, garray_class)))
         pd_error(x, "%s: no such array", x->x_arrayname->s_name);
-    else if (!garray_getfloatarray(a, &npoints, &vec))
+    else if (!garray_getfloatwords(a, &npoints, &vec))
         pd_error(x, "%s: bad template for tabread4", x->x_arrayname->s_name);
     else if (npoints < 4)
         outlet_float(x->x_obj.ob_outlet, 0);
     else if (f <= 1)
-        outlet_float(x->x_obj.ob_outlet, vec[1]);
+        outlet_float(x->x_obj.ob_outlet, vec[1].w_float);
     else if (f >= npoints - 2)
-        outlet_float(x->x_obj.ob_outlet, vec[npoints - 2]);
+        outlet_float(x->x_obj.ob_outlet, vec[npoints - 2].w_float);
     else
     {
         int n = f;
-        float a, b, c, d, cminusb, frac, *fp;
+        float a, b, c, d, cminusb, frac;
+        t_word *wp;
         if (n >= npoints - 2)
             n = npoints - 3;
-        fp = vec + n;
+        wp = vec + n;
         frac = f - n;
-        a = fp[-1];
-        b = fp[0];
-        c = fp[1];
-        d = fp[2];
+        a = wp[-1].w_float;
+        b = wp[0].w_float;
+        c = wp[1].w_float;
+        d = wp[2].w_float;
         cminusb = c-b;
         outlet_float(x->x_obj.ob_outlet, b + frac * (
             cminusb - 0.1666667f * (1.-frac) * (
@@ -961,18 +964,18 @@ typedef struct _tabwrite
 {
     t_object x_obj;
     t_symbol *x_arrayname;
-    float x_ft1;
+    t_float x_ft1;
 } t_tabwrite;
 
 static void tabwrite_float(t_tabwrite *x, t_float f)
 {
     int i, vecsize;
     t_garray *a;
-    t_float *vec;
+    t_word *vec;
 
     if (!(a = (t_garray *)pd_findbyclass(x->x_arrayname, garray_class)))
         pd_error(x, "%s: no such array", x->x_arrayname->s_name);
-    else if (!garray_getfloatarray(a, &vecsize, &vec))
+    else if (!garray_getfloatwords(a, &vecsize, &vec))
         pd_error(x, "%s: bad template for tabwrite", x->x_arrayname->s_name);
     else
     {
@@ -981,7 +984,7 @@ static void tabwrite_float(t_tabwrite *x, t_float f)
             n = 0;
         else if (n >= vecsize)
             n = vecsize-1;
-        vec[n] = f;
+        vec[n].w_float = f;
         garray_redraw(a);
     }
 }
