@@ -22,7 +22,10 @@
 #endif
 
 #if defined (__APPLE__) || defined (__FreeBSD__)
-#define HZ CLK_TCK
+#define CLOCKHZ CLK_TCK
+#endif
+#if defined (__linux__)
+#define CLOCKHZ sysconf(_SC_CLK_TCK)
 #endif
 
 /* -------------------------- random ------------------------------ */
@@ -67,7 +70,7 @@ static void random_bang(t_random *x)
     outlet_float(x->x_obj.ob_outlet, nval);
 }
 
-static void random_seed(t_random *x, float f, float glob)
+static void random_seed(t_random *x, t_float f, t_float glob)
 {
     x->x_state = f;
 }
@@ -225,16 +228,16 @@ static void cputime_bang(t_cputime *x)
 static void cputime_bang2(t_cputime *x)
 {
 #ifdef UNISTD
-    float elapsedcpu;
+    t_float elapsedcpu;
     struct tms newcputime;
     times(&newcputime);
     elapsedcpu = 1000 * (
         newcputime.tms_utime + newcputime.tms_stime -
-            x->x_setcputime.tms_utime - x->x_setcputime.tms_stime) / HZ;
+            x->x_setcputime.tms_utime - x->x_setcputime.tms_stime) / CLOCKHZ;
     outlet_float(x->x_obj.ob_outlet, elapsedcpu);
 #endif
 #ifdef MSW
-    float elapsedcpu;
+    t_float elapsedcpu;
     FILETIME ignorethis, ignorethat;
     LARGE_INTEGER usertime, kerneltime;
     BOOL retval;
